@@ -197,7 +197,7 @@ class notion_connector:
 # Met à jour une propriété avec les elements voulu
 ##################################################
 	def updateProperties(self, elem):
-		return (self.update.update_properties()[elem['type']](elem))
+		return (self.update.update_properties(elem))
 
 ##################################################
 # Recupère tout les utilisateurs de l'access token
